kedro.framework.startup.ProjectMetadata — Kedro 0.17.6 documentation

# kedro.framework.startup.ProjectMetadata

class `kedro.framework.startup.` `ProjectMetadata`(config_file: pathlib.Path, package_name: str, project_name: str, project_path: pathlib.Path, project_version: str, source_dir: pathlib.Path)

  Structure holding project metadata derived from pyproject.toml

  Attributes

  `config_file` | Alias for field number 0
  `package_name` | Alias for field number 1
  `project_name` | Alias for field number 2
  `project_path` | Alias for field number 3
  `project_version` | Alias for field number 4
  `source_dir` | Alias for field number 5

  Methods

  `count`(value) |
  `index`(value, [start, [stop]]) | Raises ValueError if the value is not present.

  property `config_file`

    Alias for field number 0

  `count`(value) → integer – return number of occurrences of value
  `index`(value[, start[, stop]]) → integer – return first index of value.

    Raises ValueError if the value is not present.

  property `package_name`

    Alias for field number 1

  property `project_name`

    Alias for field number 2

  property `project_path`

    Alias for field number 3

  property `project_version`

    Alias for field number 4

  property `source_dir`

    Alias for field number 5